@@ -1,4 +1,4 @@
-correctVarNames <- function(tab, rowcol = TRUE, cols = NA){
+correctVarNames <- function(tab, rowcol = TRUE, cols = 1:ncol(tab)){
 
 # row- and col-names
 if (rowcol == TRUE){
@@ -16,16 +16,17 @@ repl.cols <- (1:ncol(tab))[((1:ncol(tab)) %in% cols) == FALSE]
 tab2[, repl.cols] <- tab[, repl.cols]
 
 # entries
-if (is.na(cols) == TRUE){cols <- 1:ncol(tab)}
-for (j in cols){
-    col.j <- as.character(tab[, j])
+if (identical(cols, FALSE)){
+    for (j in cols){
+        col.j <- as.character(tab[, j])
     
-    for (i in 1:nrow(tab)){
-        if (is.na(col.j[i]) == FALSE){col.j[i] <- gsub("_", "\\\\_", as.character(col.j[i]))}
-    } # end i
+        for (i in 1:nrow(tab)){
+            if (is.na(col.j[i]) == FALSE){col.j[i] <- gsub("_", "\\\\_", as.character(col.j[i]))}
+        } # end i
 
-tab2[, j] <- col.j
-} 
+    tab2[, j] <- col.j
+    } 
+}
 
 return(tab2)
 }
