@@ -14,16 +14,19 @@ for (i in 1:ncol(vars)){
     capo <- paste(nam0, " vs. ", colnames(vars)[i], ".", sep = "")
     p1 <- NA
     fish <- NA
-    if ((nlevels(v1) > 1) & (nlevels(v2) > 1)){
-        fish <- "$\\chi^2$"
-        chi <- suppressWarnings(chisq.test(v1, v2))
-        p1 <- chi$p.value
-        if (min(chi$expected) <= 5){
-            fish <- "Fisher's exact"
-            p1 <- fisher.test(v1, v2)$p.value
+    
+    if (identical(add.p, TRUE)){
+        if ((nlevels(v1) > 1) & (nlevels(v2) > 1)){
+            fish <- "$\\chi^2$"
+            chi <- suppressWarnings(chisq.test(v1, v2))
+            p1 <- chi$p.value
+            if (min(chi$expected) <= 5){
+                fish <- "Fisher's exact"
+                p1 <- fisher.test(v1, v2)$p.value
+                }
+            capo <- paste(nam0, " vs. ", colnames(vars)[i], ".", sep = "")
+            capo <- paste(capo, " $p$-value ", fish, " test: ", disp(p1), ".", sep = "")
             }
-        capo <- paste(nam0, " vs. ", colnames(vars)[i], ".", sep = "")
-        if (identical(add.p, TRUE)){capo <- paste(capo, " $p$-value ", fish, " test: ", disp(p1), ".", sep = "")}
     }
     displayKbyC(v1, v2, names = c(nam0, colnames(vars)[i]), cap = capo, lab = paste(lab0, i, sep = ""), percentage = percentage)
     tabs[[i]] <- table(v1, v2)
